<?php

/**
 * @file
 * Contains \Drupal\yamlform\Controller\YamlFormHandlerController.
 */

namespace Drupal\yamlform\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\yamlform\YamlFormHandlerManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Controller for all YAML form handlers.
 */
class YamlFormHandlerController extends ControllerBase {

  /**
   * The YAML form handler plugin manager.
   *
   * @var \Drupal\yamlform\YamlFormHandlerManager
   */
  protected $handlerManager;

  /**
   * Constructs a YamlFormHandlerController object.
   *
   * @param \Drupal\yamlform\YamlFormHandlerManager $yamlform_handler_manager
   *   The YAML form handler plugin manager.
   */
  public function __construct(YamlFormHandlerManager $yamlform_handler_manager) {
    $this->handlerManager = $yamlform_handler_manager;
  }

  /**
   * {@inheritdoc}
   *
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('plugin.manager.yamlform.handler'));
  }

  /**
   * Displays a page with an overview of all available YAML form handler plugins.
   */
  public function index() {
    $handler_definitions = $this->handlerManager->getDefinitions();

    $rows = [];
    foreach ($handler_definitions as $handler_id => $handler_definition) {
      $rows[$handler_id] = [
        $handler_id,
        $handler_definition['label'],
        $handler_definition['description'],
        $handler_definition['provider'],
      ];
    }

    ksort($rows);
    return [
      '#type' => 'table',
      '#header' => [$this->t('ID'), $this->t('Label'), $this->t('Description'), $this->t('Provided by')],
      '#rows' => $rows,
      '#empty' => $this->t('There are no enabled handlers.'),
    ];
  }

}
