<?php

/**
 * @file
 * Definition of Drupal\yamlform\test\YamlFormSubmissionFormTest.
 */

namespace Drupal\yamlform\Tests;

use Drupal\yamlform\Entity\YamlForm;

/**
 * Tests for YAML form handler plugin.
 *
 * @group YamlForm
 */
class YamlFormHandlerTest extends YamlFormTestBase {

  /**
   * Tests YAML form handler plugin.
   */
  public function testYamlFormHandler() {
    $this->drupalLogin($this->adminFormUser);

    // Get the YAML form test handler.
    $yamlform_test_handler = YamlForm::load('test_handler_test');

    // Check new submission plugin invoking.
    $this->drupalGet('yamlform/test_handler_test');
    $this->assertRaw('Invoked: preCreate');
    $this->assertRaw('Invoked: postCreate');
    $this->assertRaw('Invoked: alterInputs');
    $this->assertRaw('Invoked: alterForm');

    // Check submit submission plugin invoking.
    $sid = $this->postSubmission($yamlform_test_handler);
    $this->assertRaw('Invoked: preCreate');
    $this->assertRaw('Invoked: postCreate');
    $this->assertRaw('Invoked: alterInputs');
    $this->assertRaw('Invoked: alterForm');
    $this->assertRaw('Invoked: validateForm');
    $this->assertRaw('One two one two this is just a test');
    $this->assertRaw('Invoked: submitForm');
    $this->assertRaw('Invoked: preSave');
    $this->assertRaw('Invoked: postSave insert');
    $this->assertRaw('Invoked: postLoad');

    // Check update submission plugin invoking.
    $this->drupalPostForm('/admin/structure/yamlform/results/manage/' . $sid . '/edit', [], t('Submit'));
    $this->assertRaw('Invoked: postSave update');

    // Check delete submission plugin invoking.
    $this->drupalPostForm('/admin/structure/yamlform/results/manage/' . $sid . '/delete', [], t('Delete'));
    $this->assertRaw('Invoked: postLoad');
    $this->assertRaw('Invoked: preDelete');
    $this->assertRaw('Invoked: postDelete');
    $this->assertRaw('The yaml form submission <em class="placeholder"></em> has been deleted.');

    // Check configuration settings.
    $this->drupalPostForm('admin/structure/yamlform/manage/test_handler_test/handlers/test', ['settings[message]' => '{message}'], t('Update'));
    $this->postSubmission($yamlform_test_handler);
    $this->assertRaw('{message}');
  }

}
