<?php

/**
 * @file
 * Contains \Drupal\yamlform\YamlFormSubmissionStorage.
 */

namespace Drupal\yamlform;

use Drupal\Core\Entity\Sql\SqlContentEntityStorage;

/**
 * Defines a Controller class for YAML form submissions.
 */
class YamlFormSubmissionStorage extends SqlContentEntityStorage {

  /**
   * Delete all YAML form submissions.
   *
   * @param \Drupal\yamlform\YamlFormInterface|NULL $yamlform
   *   OPTIONAL: The YAML form to delete the submissions from.
   */
  public function deleteAll(YamlFormInterface $yamlform = NULL) {
    $query = $this->getQuery()
      ->sort('sid');

    if ($yamlform) {
      $query->condition('yamlform_id', $yamlform->id());
    }

    $entity_ids = $query->execute();
    $entities = $this->loadMultiple($entity_ids);
    $this->delete($entities);
  }

  /**
   * Get the total number of submissions.
   *
   * @param \Drupal\yamlform\YamlFormInterface|NULL $yamlform
   *   (optional) A YAML form. If set the total number of submissions for the
   *   YAML form will be returned.
   *
   * @return int
   *   Total number of submissions
   */
  public function getTotal(YamlFormInterface $yamlform = NULL) {
    $query = $this->getQuery()->count();
    if ($yamlform) {
      $query->condition('yamlform_id', $yamlform->id());
    }
    return $query->execute();
  }

}
